@@ -306,7 +306,7 @@ class AutoPlot():
                     legend_label = 'Backtest Net Asset Value')
         
         navfig.xaxis.major_label_overrides = {
-                    i: date.strftime('%b %d') for i, date in enumerate(pd.to_datetime(self.data["date"]))
+                    i: date.strftime('%b %d %Y') for i, date in enumerate(pd.to_datetime(self.data["date"]))
                 }
         navfig.xaxis.bounds = (0, self.data.index[-1])
         navfig.sizing_mode = 'stretch_width'
@@ -451,7 +451,7 @@ class AutoPlot():
         cplfig.add_tools(linked_crosshair)
         
         cplfig.xaxis.major_label_overrides = {
-                    i: date.strftime('%b %d') for i, date in enumerate(pd.to_datetime(self.data["date"]))
+                    i: date.strftime('%b %d %Y') for i, date in enumerate(pd.to_datetime(self.data["date"]))
                 }
         cplfig.xaxis.bounds   = (0, self.data.index[-1])
         
@@ -470,7 +470,7 @@ class AutoPlot():
                     legend_label = 'Margin Available')
         
         marfig.xaxis.major_label_overrides = {
-                    i: date.strftime('%b %d') for i, date in enumerate(pd.to_datetime(self.data["date"]))
+                    i: date.strftime('%b %d %Y') for i, date in enumerate(pd.to_datetime(self.data["date"]))
                 }
         marfig.xaxis.bounds = (0, self.data.index[-1])
         marfig.sizing_mode = 'stretch_width'
@@ -517,7 +517,9 @@ class AutoPlot():
                      'below'       : 'below',
                      'Grid'        : 'over',
                      'Pivot'       : 'over',
-                     'HalfTrend'   : 'over'}
+                     'HalfTrend'   : 'over',
+                     'multi'       : 'below',
+                     'signals'     : 'over'}
         
         # Plot indicators
         indis_over              = 0
@@ -549,10 +551,27 @@ class AutoPlot():
                     elif indi_type == 'Pivot':
                         self._plot_pivot_points(indicators[indicator], 
                                                 linked_fig)
+                    elif indi_type == 'signals':
+                        self._plot_signals(linked_fig, 
+                                           indicators[indicator]['data'])
+                        
                     else:
                         # Generic overlay indicator - plot as line
-                        linked_fig.line(x_range, 
-                                        indicators[indicator]['data'], 
+                        if type(indicators[indicator]['data']) == pd.Series:
+                            # Merge indexes
+                            merged_indicator_data = pd.merge(self.data, 
+                                                             indicators[indicator]['data'], 
+                                                             left_on='date', 
+                                                             right_index=True)
+                            line_data = merged_indicator_data[indicators[indicator]['data'].name]
+                            x_vals = line_data.index
+                            y_vals = line_data.values
+                        else:
+                            x_vals = x_range
+                            y_vals = indicators[indicator]['data']
+                        
+                        linked_fig.line(x_vals, 
+                                        y_vals, 
                                         line_width = 1.5, 
                                         legend_label = indicator,
                                         line_color = indicators[indicator]['color'] if 'color' in indicators[indicator] else colours[indis_over])
@@ -583,8 +602,50 @@ class AutoPlot():
                         if 'swings' in indicators[indicator]:
                             self._plot_swings(indicators[indicator]['swings'], 
                                               new_fig)
-                    
+                            
+                    elif indi_type == 'multi':
+                        # Plot multiple lines on the same figure
+                        new_fig = figure(plot_width     = linked_fig.plot_width,
+                                         plot_height    = 130,
+                                         title          = indicator,
+                                         tools          = linked_fig.tools,
+                                         active_drag    = linked_fig.tools[0],
+                                         active_scroll  = linked_fig.tools[1],
+                                         x_range        = linked_fig.x_range)
+                        
+                        for dataset in list(indicators[indicator].keys())[1:]:
+                            if type(indicators[indicator][dataset]['data']) == pd.Series:
+                                # Merge indexes
+                                merged_indicator_data = pd.merge(self.data, 
+                                                                 indicators[indicator][dataset]['data'], 
+                                                                 left_on='date', 
+                                                                 right_index=True)
+                                line_data = merged_indicator_data[indicators[indicator][dataset]['data'].name]
+                                x_vals = line_data.index
+                                y_vals = line_data.values
+                            else:
+                                x_vals = x_range
+                                y_vals = indicators[indicator][dataset]['data']
+                            
+                            new_fig.line(x_vals, y_vals,
+                                         line_color = indicators[indicator][dataset]['color'] if 'color' in indicators[indicator][dataset] else 'black', 
+                                         legend_label = dataset)
+                        
                     else:
+                        # Generic indicator - plot as line
+                        if type(indicators[indicator]['data']) == pd.Series:
+                            # Merge indexes
+                            merged_indicator_data = pd.merge(self.data, 
+                                                             indicators[indicator]['data'], 
+                                                             left_on='date', 
+                                                             right_index=True)
+                            line_data = merged_indicator_data[indicators[indicator]['data'].name]
+                            x_vals = line_data.index
+                            y_vals = line_data.values
+                        else:
+                            x_vals = x_range
+                            y_vals = indicators[indicator]['data']
+                            
                         new_fig = figure(plot_width     = linked_fig.plot_width,
                                          plot_height    = 130,
                                          title          = None,
@@ -594,9 +655,9 @@ class AutoPlot():
                                          x_range        = linked_fig.x_range)
                         
                         # Add glyphs
-                        new_fig.line(x_range, 
-                                     indicators[indicator]['data'],
-                                     line_color         = 'black', 
+                        new_fig.line(x_vals, 
+                                     y_vals,
+                                     line_color = indicators[indicator]['color'] if 'color' in indicators[indicator] else 'black', 
                                      legend_label       = indicator)
                         
                     indis_below    += 1
@@ -763,6 +824,20 @@ class AutoPlot():
                          'inverted_triangle', 'red', 'Sell Signals', 
                          linked_fig, 10)
     
+    def _plot_signals(self, linked_fig, signals_df):
+        ' Plots long and short entry signals over OHLC chart. '
+        
+        signals_df = signals_df.reset_index(drop = True)
+        long_arrows = signals_df[signals_df['buy'] != 0]
+        short_arrows = signals_df[signals_df['sell'] != 0]
+        
+        # Add buy and sell entry signals
+        self._plot_trade(long_arrows.index, long_arrows.buy, 
+                         'triangle', 'lightgreen', 'Buy Signals', linked_fig, 12)
+        self._plot_trade(short_arrows.index, short_arrows.sell, 
+                         'inverted_triangle', 'orangered', 'Sell Signals', 
+                         linked_fig, 12)
+    
     def _plot_grid(self, grid_levels, linked_fig, linewidth=0.5):
         for price in grid_levels:
             hline = Span(location=price, 
